@@ -720,7 +720,6 @@ class StructWithLength(Struct):
 
 
 class Table(Struct):
-
     staticSize = 2
 
     def readOffset(self, reader):
@@ -746,16 +745,15 @@ class Table(Struct):
         if value is None:
             self.writeNullOffset(writer)
         else:
-            subWriter = writer.getSubWriter(offsetSize=self.staticSize)
+            subWriter = writer.getSubWriter()
             subWriter.name = self.name
             if repeatIndex is not None:
                 subWriter.repeatIndex = repeatIndex
-            writer.writeSubTable(subWriter)
+            writer.writeSubTable(subWriter, offsetSize=self.staticSize)
             value.compile(subWriter, font)
 
 
 class LTable(Table):
-
     staticSize = 4
 
     def readOffset(self, reader):
@@ -767,7 +765,6 @@ class LTable(Table):
 
 # Table pointed to by a 24-bit, 3-byte long offset
 class Table24(Table):
-
     staticSize = 3
 
     def readOffset(self, reader):
@@ -1147,13 +1144,13 @@ class AATLookupWithDataOffset(BaseConverter):
             offsetByGlyph[glyph] = offset
         # For calculating the offsets to our AATLookup and data table,
         # we can use the regular OTTableWriter infrastructure.
-        lookupWriter = writer.getSubWriter(offsetSize=4)
+        lookupWriter = writer.getSubWriter()
         lookup = AATLookup("DataOffsets", None, None, UShort)
         lookup.write(lookupWriter, font, tableDict, offsetByGlyph, None)
 
-        dataWriter = writer.getSubWriter(offsetSize=4)
-        writer.writeSubTable(lookupWriter)
-        writer.writeSubTable(dataWriter)
+        dataWriter = writer.getSubWriter()
+        writer.writeSubTable(lookupWriter, offsetSize=4)
+        writer.writeSubTable(dataWriter, offsetSize=4)
         for d in compiledData:
             dataWriter.writeData(d)
 
@@ -1483,9 +1480,9 @@ class STXHeader(BaseConverter):
         )
         writer = OTTableWriter()
         for lookup in table.PerGlyphLookups:
-            lookupWriter = writer.getSubWriter(offsetSize=4)
+            lookupWriter = writer.getSubWriter()
             self.perGlyphLookup.write(lookupWriter, font, {}, lookup, None)
-            writer.writeSubTable(lookupWriter)
+            writer.writeSubTable(lookupWriter, offsetSize=4)
         return writer.getAllData()
 
     def _compileLigComponents(self, table, font):
